==> trade-center-api-0.0.8-20160728.123243-2-sources.jar: cn/com/duiba/order/center/api/dto/CreditsCallbackMessage.java <==
package cn.com.duiba.order.center.api.dto;

import java.util.Map;

/**
 * 扣积分响应结果消息封装类
 */
public class CreditsCallbackMessage {

	public static final String CALLBACK_TYPE_FAILED = "failed";
	public static final String CALLBACK_TYPE_CANCELLED = "cancelled";
	public static final String CALLBACK_TYPE_COMPLETED = "completed";

	private String relationId;
	private String relationType;
	private String appId;
	private String consumerId;
	private String callbackType; // failed,completed,cancelled
	private String httpUrl;
	private String message;
	private Map<String, String> params;

	public String getRelationId() {
		return relationId;
	}

	public void setRelationId(String relationId) {
		this.relationId = relationId;
	}

	public String getRelationType() {
		return relationType;
	}

	public void setRelationType(String relationType) {
		this.relationType = relationType;
	}

	public String getAppId() {
		return appId;
	}

	public void setAppId(String appId) {
		this.appId = appId;
	}

	public String getConsumerId() {
		return consumerId;
	}

	public void setConsumerId(String consumerId) {
		this.consumerId = consumerId;
	}

	public String getCallbackType() {
		return callbackType;
	}

	public void setCallbackType(String callbackType) {
		this.callbackType = callbackType;
	}

	public String getMessage() {
		return message;
	}

	public void setMessage(String message) {
		this.message = message;
	}

	public Map<String, String> getParams() {
		return params;
	}

	public void setParams(Map<String, String> params) {
		this.params = params;
	}

	public String getHttpUrl() {
		return httpUrl;
	}

	public void setHttpUrl(String httpUrl) {
		this.httpUrl = httpUrl;
	}

}

==> trade-center-api-3.0.15-20251104.055612-5-sources.jar: cn/com/duiba/order/center/api/dto/CreditsCallbackMessage.java <==
package cn.com.duiba.order.center.api.dto;


import cn.com.duiba.api.bo.credits.CreditsResponse;

import java.io.Serializable;
import java.util.HashMap;
import java.util.Map;

/**
 * 扣/加积分响应结果消息封装类
 */
public class CreditsCallbackMessage implements Serializable, CreditsResponse {

	/**
	 * 
	 */
	private static final long serialVersionUID = 7020165279644014518L;
	
	public static final String CALLBACK_TYPE_FAILED = "failed";
	public static final String CALLBACK_TYPE_CANCELLED = "cancelled";
	public static final String CALLBACK_TYPE_COMPLETED = "completed";

	private String relationId;
	private String relationType;
	private String appId;
	private String consumerId;
	private String callbackType; // failed,completed,cancelled
	private String httpUrl;
	private String message;
	private Map<String, String> params;
	/**
	 * 额外信息,方便信息从thirdparty
	 */
	private Map<String, String> extraInfo = new HashMap<>();

	public String getRelationId() {
		return relationId;
	}

	public void setRelationId(String relationId) {
		this.relationId = relationId;
	}

	public String getRelationType() {
		return relationType;
	}

	public void setRelationType(String relationType) {
		this.relationType = relationType;
	}

	public String getAppId() {
		return appId;
	}

	public void setAppId(String appId) {
		this.appId = appId;
	}

	public String getConsumerId() {
		return consumerId;
	}

	public void setConsumerId(String consumerId) {
		this.consumerId = consumerId;
	}

	public String getCallbackType() {
		return callbackType;
	}

	public void setCallbackType(String callbackType) {
		this.callbackType = callbackType;
	}

	public String getMessage() {
		return message;
	}

	public void setMessage(String message) {
		this.message = message;
	}

	public Map<String, String> getParams() {
		return params;
	}

	public void setParams(Map<String, String> params) {
		this.params = params;
	}

	public String getHttpUrl() {
		return httpUrl;
	}

	public void setHttpUrl(String httpUrl) {
		this.httpUrl = httpUrl;
	}

	public Map<String, String> getExtraInfo() {
		return extraInfo;
	}

	public void setExtraInfo(Map<String, String> extraInfo) {
		this.extraInfo = extraInfo;
	}
}
